# German and Dutch Translations of the Artificial-Social-Agent Questionnaire Instrument for Evaluating Human-Agent Interactions

**Author**: Nele Albers

**Date**: June 2024


This README-file is meant to give you an overview of the data, analysis code, and final translated questionnaires underlying our paper "German and Dutch Translations of the Artificial-Social-Agent Questionnaire Instrument for Evaluating Human-Agent Interactions."

One author who did not write the analysis code and data documentation checked them and filled in the checklist "ChecklistDataRepositoryReview_ASAQ-Translation_signed.pdf."

Authored by Nele Albers, Andrea Bönsch, Jonathan Ehret, Boleslav A. Khodakov, and Willem-Paul Brinkman.


# Types of analyses and content

We provide code to reproduce these analyses:

1) Data preprocessing:
   - Data anonymization code: "Data/anonymize_and_preprocess_summative_dutch_final_to_publish.py" and "Data/anonymize_and_preprocess_summative_german_final_to_publish.py"
   - Preprocess the Dutch ratings data on the first half of the constructs/dimensions: "Data Transformation Summative Dutch first half.Rmd"
   - Preprocess the Dutch ratings data on the second half of the constructs/dimensions: "Data Transformation Summative Dutch second half.Rmd"
   - Preprocess the German ratings data on the first half of the constructs/dimensions: "Data Transformation Summative first half.Rmd"
   - Preprocess the German ratings data on the second half of the constructs/dimensions: "Data Transformation Summative second half.Rmd"
   - Create a data file for the cultural comparison: "Transformation Culture_from_raw_English.Rmd"
   
2) Correlation and variation between the English and translated ASA questionnaires
   - Dutch: "DutchSummative.Rmd". This allows to reproduce the Dutch translation-related values from Section 4.1 and Section 4.2, the Dutch translation-related values from Table 1, values from Table A3, values from Table A5, and values from Table A7.
   - German: "GermanSummative.Rmd". This allows to reproduce the German translation-related values from Section 4.1 and Section 4.2, the German translation-related values from Table 1, values from Table A4, values from Table A6, and values from Table A8.

3) Comparison of human-ASA interaction experiences between different language samples
   - "cultural_comparison_pairwise.Rmd". This allows to reproduce the values from Tables A9, A10, and A11 in the Appendix.

4) Participant characteristics:
   - "participant_characteristics.Rmd": This allows to reproduce the age, gender, and education level of the participants of the summative analysis studies reported in Table A1 in the Appendix.
   
You can use the above .Rmd-files to reproduce the analyses yourself. For each .Rmd-file, there is also a knitted .pdf-file that shows the results that we obtained.


We further provide the following content/material:

1) Final Dutch and German questionnaires:
   - We provide the final Dutch and German questionnaires in the folder "Final_Questionnaires."

2) ASA chart generators:
   - Code to visualize the ASAQ scores of three different ASAs in English ("Chart_Generators/asachart_3ASAs_english.html")
   - Code to visualize the ASAQ scores of two different ASAs in German ("Chart_Generators/asachart_2ASAs_german.html")
   - Code to visualize the ASAQ scores of one ASA in German ("Chart_Generators/asachart_singleASA_german.html")
   - Code to visualize the ASAQ scores of one ASA in Dutch ("Chart_Generators/asachart_singleASA_dutch.html")

3) Data from the summative analysis:
   - Data from participants' Prolific profiles (e.g., "Data/prolific_export_final_eval_dutch_first_half_final_2023_12_15_anonym.csv")
   - Data on the ASAQ ratings (e.g., "Data/Final_ASA_Dutch_Summative_First_Half_2023_12_15_anonym.csv")


# How to run the analyses yourself

This section is to explain how you can run the analyses yourself.


## Requirements

You need to have Docker installed. Moreover, to reproduce the preprocessing for the cultural comparison analysis, you need to download the file "ASAQ_ConstructValidity_p532.xlsx" from this repository: https://doi.org/10.4121/19758436.v6. Then, place the file in the "Data"-folder.


## Steps to reproduce analyses

The reproduction of our code is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/asaq_dutch_german`. If this fails, pull the Docker image from Dockerhub instead.
      - Pull the Docker image from Dockerhub via `docker pull gbna4/asaq_dutch_german`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/asaq_dutch_german`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the analysis results using the .Rmd-files mentioned earlier. If this fails (e.g., because of an error that says "cannot open the connection"), consider knitting the the .Rmd-file as described in the section below.


## Knitting R markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/asaq_dutch_german`. If this fails, pull the Docker image from Dockerhub instead.
      - Pull the Docker image from Dockerhub via `docker pull gbna4/asaq_dutch_german`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/asaq_dutch_german /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


# Files and folders

This directory contains the following files and folders:

- Chart_Generators:
   - asachart_2ASAs_german.html: code to visualize the ASAQ scores of two ASAs in German.
   - asachart_3ASAs_english.html: code to visualize the ASAQ scores of three ASAs in English.
   - asachart_singleASA_dutch.html: code to visualize the ASAQ scores of one ASA in Dutch.
   - asachart_singleASA_german.html: code to visualize the ASAQ scores of one ASA in German.

- Data: 
   - anonymize_and_preprocess_summative_dutch_final_to_publish.py: Code used to initially anonymize the data from the Dutch summative analysis study.
   - anonymize_and_preprocess_summative_german_final_to_publish.py: Code used to initially anonymize the data from the German summative analysis study.
   - Final_ASA_Dutch_Summative_First_Half_Final_2023_12_15_anonym.csv: Data on the ratings of the first half of the constructs/dimensions for the Dutch summative analysis.
   - Final_ASA_Dutch_Summative_Second_Half_Final_2023_12_15_anonym.csv: Data on the ratings of the second half of the constructs/dimensions for the Dutch summative analysis.
   - Final_ASA_German_Summative_First_Half_Final_2023_07_15_anonym.csv: Data on the ratings of the first half of the constructs/dimensions for the German summative analysis.
   - Final_ASA_German_Summative_Second_Half_Final_2023_07_15_anonym.csv: Data on the ratings of the second half of the constructs/dimensions for the German summative analysis.
   - prolific_export_final_eval_dutch_first_half_final_2023_12_15_anonym.csv: Prolific profile data of the participants who rated the first half of the constructs/dimensions for the Dutch summative analysis.
   - prolific_export_final_eval_dutch_second_half_final_2023_12_15_anonym.csv: Prolific profile data of the participants who rated the second half of the constructs/dimensions for the Dutch summative analysis.
   - prolific_export_final_eval_german_first_half_final_2023_07_15_anonym.csv: Prolific profile data of the participants who rated the first half of the constructs/dimensions for the German summative analysis.
   - prolific_export_final_eval_german_second_half_final_2023_07_15_anonym.csv: Prolific profile data of the participants who rated the second half of the constructs/dimensions for the German summative analysis.
   - There are further data explanation files that explain the columns in the data files. For example, the file "prolific_export_final_eval_german_data_explanation.xlsx" explains the columns in the files "prolific_export_final_eval_german_first_half_final_2023_07_15_anonym.csv" and "prolific_export_final_eval_german_second_half_final_2023_07_15_anonym.csv."

- Final_Questionnaires:
   - Vragenlijstinstrument_voor_Kunstmatige_Sociale_Agenten.pdf: Final Dutch ASAQ.
   - Artificial_Social_Agent_Fragebogen_Instrument.pdf: Final German ASAQ.

- ChecklistDataRepositoryReview_ASAQ-Translation_signed.pdf: Code and data checklist filled in by one of the authors.
- cultural_comparison_pairwise.pdf: Our results on the comparison of human-ASA interaction experiences between different language samples.
- cultural_comparison_pairwise.Rmd: File to reproduce the results above.
- "Data Transformation Summative Dutch first half.Rmd": File to reproduce our preprocessing of the ratings data of the first half of the constructs/dimensions for the Dutch summative analysis.
- "Data Transformation Summative Dutch second half.Rmd": File to reproduce our preprocessing of the ratings data of the second half of the constructs/dimensions for the Dutch summative analysis.
- "Data Transformation Summative first half.Rmd": File to reproduce our preprocessing of the ratings data of the first half of the constructs/dimensions for the German summative analysis.
- "Data Transformation Summative second half.Rmd": File to reproduce our preprocessing of the ratings data of the second half of the constructs/dimensions for the German summative analysis.
- data_culture_DE_EN_NL.sav: File for the cultural comparison analysis created through the file "Transformation Culture_from_raw_English.Rmd."
- "Data-Transformation-Summative-Dutch-first-half.pdf": Our results from preprocessing of the ratings data of the first half of the constructs/dimensions for the Dutch summative analysis.
- "Data-Transformation-Summative-Dutch-second-half.pdf": Our results from preprocessing of the ratings data of the second half of the constructs/dimensions for the Dutch summative analysis.
- "Data-Transformation-Summative-first-half.pdf": Our results from preprocessing of the ratings data of the first half of the constructs/dimensions for the German summative analysis.
- "Data-Transformation-Summative-second-half.pdf": Our results from preprocessing of the ratings data of the second half of the constructs/dimensions for the German summative analysis.
- Dockerfile: To build the Docker image yourself.
- DutchSummative.pdf: Our results from computing the correlation and variation between the English and Dutch questionnaire.
- DutchSummative.Rmd: File to reproduce the results above.
- GermanSummative.pdf: Our results from computing the correlation and variation between the English and German questionnaire.
- GermanSummative.Rmd: File to reproduce the results above.
- JAGS-4.3.0.tar.gaz: Needed to build the Docker image yourself.
- participant_characteristics.pdf: Our results from computing the participant characteristics (e.g., age, gender).
- participant_characteristics.Rmd: File to reproduce the results above.
- README.md/README.pdf: This README-file.
- references.bib: References used in the .Rmd-files.
- summative_first_half_transformed_dutch.sav: Preprocessed data for computing the correlation and variation between the English and Dutch questionnaire for the first half of the constructs/dimensions.
- summative_first_half_transformed_german.sav: Preprocessed data for computing the correlation and variation between the English and German questionnaire for the first half of the constructs/dimensions.
- summative_second_half_transformed_dutch.sav: Preprocessed data for computing the correlation and variation between the English and Dutch questionnaire for the second half of the constructs/dimensions.
- summative_second_half_transformed_german.sav: Preprocessed data for computing the correlation and variation between the English and German questionnaire for the second half of the constructs/dimensions.
- "Transformation Culture_from_raw_English.Rmd": File to preprocess the data for the cultural comparison analysis.
- Transformation-Culture_from_raw_English.pdf: Our results from preprocessing the data for the cultural comparison analysis.
